package com.example.duplicate.service.impl;

import com.example.duplicate.controller.param.PageRequest;
import com.example.duplicate.controller.param.SginBasicDto;
import com.example.duplicate.controller.vo.PageBasic;
import com.example.duplicate.controller.vo.RcvBasic;

import com.example.duplicate.infrastructure.dao.BasicMapper;
import com.example.duplicate.service.RcvBasicService;
import com.example.utils.CommonResult;
import com.example.utils.PageResult;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.sql.*;
import java.time.LocalDate;
import java.time.Period;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @ClassName RcvBasicServiceImpl
 * @Description
 * @Author linjj
 * @Date 2025/6/20 12:25
 * @Version 1.0
 */
@Service
@Slf4j
public class RcvBasicServiceImpl implements RcvBasicService {
    @Autowired
    private BasicMapper basicMapper;
    @Override
    public CommonResult<?> Sign(String patientId) {
        try {
        if (StringUtils.isBlank(patientId)){
            return CommonResult.failed("病案号不能为空！");
        }
        //查询是否已经存在数据，存在数据不在新增，直接返回已经签收
        List<String> idByPatientId = basicMapper.getIDByPatientId(patientId);
        if (!CollectionUtils.isEmpty(idByPatientId)) {
            return CommonResult.failed("病案ID【" + patientId + "】已签收过，不能重复签收");
        }
        SginBasicDto sginBasicDto=new SginBasicDto();
        // SQL Server连接信息
        String url = "jdbc:sqlserver://10.1.1.21:1433;databaseName=trasen;encrypt=false;useUnicode=true;characterEncoding=utf-8";
        String username = "SZJK";
        String password = "SZJK";
//        String url = "jdbc:sqlserver://127.0.0.1:1433;databaseName=trasen;encrypt=false;useUnicode=true;characterEncoding=utf-8";
//        String username = "sa";
//        String password = "admin123";

        // SQL语句根据patientId查询患者基础信息
        String selectQuery = "SELECT * FROM dbo.V_sz_cybrxx WHERE 病案号='" + patientId + "'";
        log.info("查询语句为："+selectQuery);

            // 1. 加载SQL Server JDBC驱动
            Class.forName("com.microsoft.sqlserver.jdbc.SQLServerDriver");

            // 2. 建立数据库连接
            Connection connection = DriverManager.getConnection(url, username, password);

            // 3. 创建Statement对象用于执行SQL语句
            Statement statement = connection.createStatement();
            // 4. 执行查询操作
            ResultSet resultSet = statement.executeQuery(selectQuery);
            // 5. 处理查询结果并映射到RcvBasicVO对象
            while (resultSet.next()) {
                sginBasicDto.setPatientId(resultSet.getString("病案号"));
                sginBasicDto.setAdmissTimes(resultSet.getInt("住院次数"));
                sginBasicDto.setDisDate(resultSet.getDate("出院日期"));
                sginBasicDto.setName(resultSet.getString("姓名"));
                String sex = resultSet.getString("性别");
                if (sex.equals("1")){
                    sginBasicDto.setSex("男");
                }
                if (sex.equals("2")){
                    sginBasicDto.setSex("女");
                }
                if (sex.equals("3")){
                    sginBasicDto.setSex("不详");
                }
                sginBasicDto.setBedNumber(resultSet.getString("床位号"));
                sginBasicDto.setAttendingName(resultSet.getString("责任人"));
                sginBasicDto.setRevoveryState("已签收");
                sginBasicDto.setRevoveryTime(new Timestamp(System.currentTimeMillis()));
            }
            // 6. 关闭资源
            resultSet.close();
            statement.close();
            connection.close();
            //先插入数据到2.0中
            if (!getObjectCommonResult(sginBasicDto)){
                log.error("传送到病案数码系统失败");
                return CommonResult.failed("传送到病案数码系统失败,请联系管理员");
            }
            //插入数据
            if (!basicMapper.addBasic(sginBasicDto)){
                log.error("签收失败");
                return CommonResult.failed("签收失败");
            }
        } catch (Exception e) {
            log.error("签收失败： " + e,e.getMessage());
            return CommonResult.failed("签收失败： " + e.getMessage());
        }
        return CommonResult.success("签收完成");
    }

    private Boolean getObjectCommonResult(SginBasicDto sginBasicDto) {
        // SQL Server连接信息
//        String url = "jdbc:sqlserver://127.0.0.1:1433;databaseName=gm_record;encrypt=false;useUnicode=true;characterEncoding=utf-8";
//        String username = "sa";
//        String password = "admin123";
        String url = "jdbc:sqlserver://10.1.1.147:1433;databaseName=csssemrrcord;encrypt=false;useUnicode=true;characterEncoding=utf-8";
        String username = "sa";
        String password = "xjgs+docus911";
        // 插入语句
        String insertQuery = "INSERT INTO commomtable (patient_id,admiss_times, inpatient_no, name, sex, dis_date, attending) VALUES (replace(newid(), '-', ''),?, ?, ?, ?, ?, ?);";
        log.info("执行的SQL语句为: " + insertQuery);
        try {
            // 1. 加载SQL Server JDBC驱动
            Class.forName("com.microsoft.sqlserver.jdbc.SQLServerDriver");

            // 2. 建立数据库连接
            Connection connection = DriverManager.getConnection(url, username, password);

            // 3. 创建PreparedStatement对象用于执行SQL语句
            PreparedStatement preparedStatement = connection.prepareStatement(insertQuery);

            // 4. 设置参数
            preparedStatement.setInt(1, sginBasicDto.getAdmissTimes());
            preparedStatement.setString(2, sginBasicDto.getPatientId());
            preparedStatement.setString(3, sginBasicDto.getName());
            preparedStatement.setString(4, sginBasicDto.getSex());
            preparedStatement.setDate(5, new java.sql.Date(sginBasicDto.getDisDate().getTime()));
            preparedStatement.setString(6, sginBasicDto.getAttendingName());

            // 5. 执行插入操作
            preparedStatement.executeUpdate();

            // 6. 关闭资源
            preparedStatement.close();
            connection.close();
        } catch (Exception e) {
            log.error("传送到病案数码系统失败： " + e,e.getMessage());
            return false;
        }
        log.info("插入2.0中成功");
        return true;
    }

    @Override
    public CommonResult<PageResult<PageBasic>>pageAll(PageRequest pageRequest) {
        PageResult<PageBasic> pageResult = null;
        try {
            // 设置分页参数
            PageHelper.startPage(pageRequest.getPage(), pageRequest.getSize());
            List<PageBasic> pageAll = basicMapper.getPageAll(pageRequest);
            pageResult = new PageResult<>(pageAll);
        } catch (Exception e) {
            log.error("系统异常： " + e.getMessage());
           return CommonResult.failed("系统异常");
        }
        return CommonResult.success(pageResult);
    }

    @Override
    public CommonResult<?> UpdateSign(String patientId,String revoveryState) {
        if (revoveryState.equals("已签收")){
            basicMapper.UpdateState(patientId,"未签收");
            return CommonResult.success("取消签收成功");
        }
        if (revoveryState.equals("未签收")){
            basicMapper.UpdateState(patientId,"已签收");
            return CommonResult.success("签收成功");
        }
        return null;
    }
}
